@@ -9,6 +9,7 @@
 
 #include "dolphinnavigatorswidgetaction.h"
 #include "dolphintabpage.h"
+#include "views/draganddrophelper.h"
 
 #include <QTabWidget>
 #include <QUrl>
@@ -69,6 +70,11 @@ public:
      */
     void refreshViews();
 
+    /**
+     * Update the name of the tab with the index \a index.
+     */
+    void updateTabName(int index);
+
     /**
      * @return Whether any of the tab pages has @p url opened
      * in their primary or secondary view.
@@ -106,6 +112,11 @@ Q_SIGNALS:
      */
     void currentUrlChanged(const QUrl &url);
 
+    /**
+     * Is emitted when the url of any tab has been changed (including the current tab).
+     */
+    void urlChanged(const QUrl &url);
+
 public Q_SLOTS:
     /**
      * Opens a new view with the current URL that is part of a tab and activates
@@ -198,6 +209,12 @@ private Q_SLOTS:
      */
     void openNewActivatedTab(int index);
 
+    /**
+     * Is connected to the KTabBar signal receivedDragMoveEvent.
+     * Allows dragging and dropping files onto tabs.
+     */
+    void tabDragMoveEvent(int tab, QDragMoveEvent *event);
+
     /**
      * Is connected to the KTabBar signal receivedDropEvent.
      * Allows dragging and dropping files onto tabs.
@@ -260,6 +277,8 @@ private:
      */
     const std::optional<const ViewIndex> viewShowingItem(const QUrl &item) const;
 
+    DragAndDropHelper m_dragAndDropHelper;
+
 private:
     QPointer<DolphinTabPage> m_lastViewedTab;
     QPointer<DolphinNavigatorsWidgetAction> m_navigatorsWidget;
