@@ -24,6 +24,7 @@
 #include <QGraphicsView>
 #include <QPixmapCache>
 #include <QStyleOption>
+#include <QVariantAnimation>
 
 // #define KSTANDARDITEMLISTWIDGET_DEBUG
 
@@ -535,6 +536,7 @@ QRectF KStandardItemListWidget::selectionToggleRect() const
 {
     const_cast<KStandardItemListWidget *>(this)->triggerCacheRefreshing();
 
+    const QRectF widgetIconRect = iconRect();
     const int widgetIconSize = iconSize();
     int toggleSize = KIconLoader::SizeSmall;
     if (widgetIconSize >= KIconLoader::SizeEnormous) {
@@ -543,7 +545,7 @@ QRectF KStandardItemListWidget::selectionToggleRect() const
         toggleSize = KIconLoader::SizeSmallMedium;
     }
 
-    QPointF pos = iconRect().topLeft();
+    QPointF pos = widgetIconRect.topLeft();
 
     // If the selection toggle has a very small distance to the
     // widget borders, the size of the selection toggle will get
@@ -564,6 +566,10 @@ QRectF KStandardItemListWidget::selectionToggleRect() const
         pos.setX(0);
     }
 
+    if (QApplication::isRightToLeft()) {
+        pos.setX(widgetIconRect.right() - (pos.x() + toggleSize - widgetIconRect.left()));
+    }
+
     return QRectF(pos, QSizeF(toggleSize, toggleSize));
 }
 
@@ -589,6 +595,55 @@ QPixmap KStandardItemListWidget::createDragPixmap(const QStyleOptionGraphicsItem
     return clippedPixmap;
 }
 
+void KStandardItemListWidget::startActivateSoonAnimation(int timeUntilActivation)
+{
+    if (m_activateSoonAnimation) {
+        m_activateSoonAnimation->stop(); // automatically DeleteWhenStopped
+    }
+
+    m_activateSoonAnimation = new QVariantAnimation{this};
+    m_activateSoonAnimation->setStartValue(0.0);
+    m_activateSoonAnimation->setEndValue(1.0);
+    m_activateSoonAnimation->setDuration(timeUntilActivation);
+
+    const QVariant originalIconName{data()["iconName"]};
+    connect(m_activateSoonAnimation, &QVariantAnimation::valueChanged, this, [originalIconName, this](const QVariant &value) {
+        auto progress = value.toFloat();
+
+        QVariant wantedIconName;
+        if (progress < 0.333) {
+            wantedIconName = "folder-open";
+        } else if (progress < 0.666) {
+            wantedIconName = originalIconName;
+        } else {
+            wantedIconName = "folder-open";
+        }
+
+        QHash<QByteArray, QVariant> itemData{data()};
+        if (itemData["iconName"] != wantedIconName) {
+            itemData.insert("iconName", wantedIconName);
+            setData(itemData);
+            invalidateIconCache();
+        }
+    });
+
+    connect(m_activateSoonAnimation, &QObject::destroyed, this, [originalIconName, this]() {
+        QHash<QByteArray, QVariant> itemData{data()};
+        if (itemData["iconName"] == "folder-open") {
+            itemData.insert("iconName", originalIconName);
+            setData(itemData);
+            invalidateIconCache();
+        }
+    });
+
+    m_activateSoonAnimation->start(QAbstractAnimation::DeleteWhenStopped);
+}
+
+bool KStandardItemListWidget::isIconControlledByActivateSoonAnimation() const
+{
+    return m_activateSoonAnimation && data()["iconName"] == "folder-open";
+}
+
 KItemListWidgetInformant *KStandardItemListWidget::createInformant()
 {
     return new KStandardItemListWidgetInformant();
@@ -736,7 +791,9 @@ void KStandardItemListWidget::styleOptionChanged(const KItemListStyleOption &cur
 
 void KStandardItemListWidget::hoveredChanged(bool hovered)
 {
-    Q_UNUSED(hovered)
+    if (!hovered && m_activateSoonAnimation) {
+        m_activateSoonAnimation->stop(); // automatically DeleteWhenStopped
+    }
     m_dirtyLayout = true;
 }
 
@@ -980,7 +1037,7 @@ void KStandardItemListWidget::updatePixmapCache()
 
         int sequenceIndex = hoverSequenceIndex();
 
-        if (values.contains("hoverSequencePixmaps")) {
+        if (values.contains("hoverSequencePixmaps") && !isIconControlledByActivateSoonAnimation()) {
             // Use one of the hover sequence pixmaps instead of the default
             // icon pixmap.
 
@@ -1000,7 +1057,7 @@ void KStandardItemListWidget::updatePixmapCache()
             }
         }
 
-        if (m_pixmap.isNull()) {
+        if (m_pixmap.isNull() && !isIconControlledByActivateSoonAnimation()) {
             m_pixmap = values["iconPixmap"].value<QPixmap>();
         }
 
@@ -1080,7 +1137,11 @@ void KStandardItemListWidget::updatePixmapCache()
     } else {
         // Center horizontally and vertically within the icon-area
         const TextInfo *textInfo = m_textInfo.value("text");
-        m_pixmapPos.setX(textInfo->pos.x() - 2.0 * padding - (scaledIconSize + m_scaledPixmapSize.width()) / 2.0);
+        if (QApplication::isRightToLeft() && m_layout == CompactLayout) {
+            m_pixmapPos.setX(size().width() - padding - (scaledIconSize + m_scaledPixmapSize.width()) / 2.0);
+        } else {
+            m_pixmapPos.setX(textInfo->pos.x() - 2.0 * padding - (scaledIconSize + m_scaledPixmapSize.width()) / 2.0);
+        }
 
         // Derive icon's vertical center from the center of the text frame, including
         // any necessary adjustment if the font's midline is offset from the frame center
@@ -1123,6 +1184,9 @@ void KStandardItemListWidget::updateTextsCache()
         textOption.setAlignment(Qt::AlignHCenter);
         break;
     case CompactLayout:
+        textOption.setAlignment(QApplication::isRightToLeft() ? Qt::AlignRight : Qt::AlignLeft);
+        textOption.setWrapMode(QTextOption::NoWrap);
+        break;
     case DetailsLayout:
         textOption.setAlignment(Qt::AlignLeft);
         textOption.setWrapMode(QTextOption::NoWrap);
@@ -1352,9 +1416,9 @@ void KStandardItemListWidget::updateCompactLayoutTextCache()
     const qreal textLinesHeight = qMax(visibleRoles().count(), 1) * lineSpacing;
 
     qreal maximumRequiredTextWidth = 0;
-    const qreal x = option.padding * 3 + iconSize();
+    const qreal x = QApplication::isRightToLeft() ? option.padding : option.padding * 3 + iconSize();
     qreal y = qRound((widgetHeight - textLinesHeight) / 2);
-    const qreal maxWidth = size().width() - x - option.padding;
+    const qreal maxWidth = size().width() - iconSize() - 4 * option.padding;
     for (const QByteArray &role : std::as_const(m_sortedVisibleRoles)) {
         const QString text = escapeString(roleText(role, values));
         TextInfo *textInfo = m_textInfo.value(role);
