@@ -9,6 +9,7 @@
 #define BACKGROUNDCOLORHELPER_H
 
 #include <QColor>
+#include <QObject>
 #include <QPointer>
 
 #include <memory>
@@ -21,8 +22,9 @@ namespace SelectionMode
 /**
  * @brief A Singleton class for managing the colors of selection mode widgets.
  */
-class BackgroundColorHelper
+class BackgroundColorHelper : public QObject
 {
+    Q_OBJECT
 public:
     static BackgroundColorHelper *instance();
 
@@ -32,6 +34,9 @@ public:
      */
     void controlBackgroundColor(QWidget *widget);
 
+protected:
+    bool eventFilter(QObject *obj, QEvent *event) override;
+
 private:
     BackgroundColorHelper();
 
